Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(167)

Unified Diff: net/base/x509_util.h

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rename all the things Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/base/x509_util.h
diff --git a/net/base/x509_util.h b/net/base/x509_util.h
index 825ee023296ea1c13cc0f4f2a9b70b0f7865e05d..286a7df43757f11ae4fe33b8c44627e5ef4acc33 100644
--- a/net/base/x509_util.h
+++ b/net/base/x509_util.h
@@ -19,15 +19,15 @@ namespace net {
namespace x509_util {
// Creates an origin bound certificate containing the public key in |key|.
// Web origin, serial number and validity period are given as
wtc 2012/03/15 23:46:38 "Domain" should match the new name of the second p
mattm 2012/03/16 22:22:00 Done.
// parameters. The certificate is signed by the private key in |key|.
// The hashing algorithm for the signature is SHA-1.
//
// See Internet Draft draft-balfanz-tls-obc-00 for more details:
// http://tools.ietf.org/html/draft-balfanz-tls-obc-00
-bool NET_EXPORT_PRIVATE CreateOriginBoundCertEC(crypto::ECPrivateKey* key,
- const std::string& origin,
+bool NET_EXPORT_PRIVATE CreateServerBoundCertEC(crypto::ECPrivateKey* key,
wtc 2012/03/15 23:46:38 This function should be named either OriginBound o
mattm 2012/03/16 22:22:00 Done.
+ const std::string& server,
uint32 serial_number,
base::Time not_valid_before,
base::Time not_valid_after,
@@ -19,15 +19,15 @@ namespace net {
namespace x509_util {
-// Creates an origin bound certificate containing the public key in |key|.
-// Web origin, serial number and validity period are given as
+// Creates a server bound certificate containing the public key in |key|.
+// Domain, serial number and validity period are given as
wtc 2012/03/15 23:46:38 "Domain" should match the new name of the second p
mattm 2012/03/16 22:22:00 Done.

Powered by Google App Engine
This is Rietveld 408576698